@@ -33,7 +33,6 @@
 #include "archiveentry.h"
 #include "cliproperties.h"
 #include "kerfuffle_export.h"
-#include "part/archivemodel.h"
 
 #include <QProcess>
 #include <QRegularExpression>
@@ -56,25 +55,24 @@ public:
     OperationMode m_operationMode = List;
 
     explicit CliInterface(QObject *parent, const QVariantList & args);
-    virtual ~CliInterface();
+    ~CliInterface() override;
 
-    virtual int copyRequiredSignals() const Q_DECL_OVERRIDE;
+    int copyRequiredSignals() const override;
 
-    virtual bool list() Q_DECL_OVERRIDE;
-    virtual bool extractFiles(const QVector<Archive::Entry*> &files, const QString &destinationDirectory, const ExtractionOptions &options) Q_DECL_OVERRIDE;
-    virtual bool addFiles(const QVector<Archive::Entry*> &files, const Archive::Entry *destination, const CompressionOptions& options, uint numberOfEntriesToAdd = 0) Q_DECL_OVERRIDE;
-    virtual bool moveFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions& options) Q_DECL_OVERRIDE;
-    virtual bool copyFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions& options) Q_DECL_OVERRIDE;
-    virtual bool deleteFiles(const QVector<Archive::Entry*> &files) Q_DECL_OVERRIDE;
-    virtual bool addComment(const QString &comment) Q_DECL_OVERRIDE;
-    virtual bool testArchive() Q_DECL_OVERRIDE;
+    bool list() override;
+    bool extractFiles(const QVector<Archive::Entry*> &files, const QString &destinationDirectory, const ExtractionOptions &options) override;
+    bool addFiles(const QVector<Archive::Entry*> &files, const Archive::Entry *destination, const CompressionOptions& options, uint numberOfEntriesToAdd = 0) override;
+    bool moveFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions& options) override;
+    bool copyFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions& options) override;
+    bool deleteFiles(const QVector<Archive::Entry*> &files) override;
+    bool addComment(const QString &comment) override;
+    bool testArchive() override;
 
     virtual void resetParsing() = 0;
     virtual bool readListLine(const QString &line) = 0;
     virtual bool readExtractLine(const QString &line) = 0;
-    bool doKill() Q_DECL_OVERRIDE;
-    bool doSuspend() Q_DECL_OVERRIDE;
-    bool doResume() Q_DECL_OVERRIDE;
+    virtual bool readDeleteLine(const QString &line);
+    bool doKill() override;
 
     /**
      * Sets if the listing should include empty lines.
@@ -99,7 +97,7 @@ public:
      */
     QStringList extractFilesList(const QVector<Archive::Entry*> &files) const;
 
-    QString multiVolumeName() const Q_DECL_OVERRIDE;
+    QString multiVolumeName() const override;
 
     CliProperties *cliProperties() const;
 
@@ -138,20 +136,20 @@ protected:
 
     void cleanUp();
 
-    CliProperties *m_cliProps = Q_NULLPTR;
+    CliProperties *m_cliProps = nullptr;
     QString m_oldWorkingDir;
     QScopedPointer<QTemporaryDir> m_tempWorkingDir;
     QScopedPointer<QTemporaryDir> m_tempAddDir;
     OperationMode m_subOperation = List;
     QVector<Archive::Entry*> m_passedFiles;
     QVector<Archive::Entry*> m_tempAddedFiles;
-    Archive::Entry *m_passedDestination = Q_NULLPTR;
+    Archive::Entry *m_passedDestination = nullptr;
     CompressionOptions m_passedOptions;
 
 #ifdef Q_OS_WIN
-    KProcess *m_process = Q_NULLPTR;
+    KProcess *m_process = nullptr;
 #else
-    KPtyProcess *m_process = Q_NULLPTR;
+    KPtyProcess *m_process = nullptr;
 #endif
 
     bool m_abortingOperation = false;
@@ -215,8 +213,8 @@ private:
     QScopedPointer<QTemporaryDir> m_extractTempDir;
     QScopedPointer<QTemporaryFile> m_commentTempFile;
     QVector<Archive::Entry*> m_extractedFiles;
-    uint m_archiveSizeOnDisk = 0;
-    uint m_listedSize = 0;
+    qulonglong m_archiveSizeOnDisk = 0;
+    qulonglong m_listedSize = 0;
 
 protected slots:
     virtual void processFinished(int exitCode, QProcess::ExitStatus exitStatus);
